@@ -77,13 +77,14 @@ def failures_out(messages: list) -> None:
 def load_contents_from_local_file(file_type: str, local_file_path: str) -> Dict:
     """Loading a local file contents
 
+    ### TODO: Add default option to load file as plain text
+
     Parameters:
         file_type (str)       : Type of file to be loaded ie. 'yaml', 'toml', 'json'
         local_file_path (str) : Path to a local TOML file to be loaded
     Returns:
         file_contents (dict) : The contents of file
     """
-    # TODO: Add default option to load file as plain text
 
     file_type = file_type.lower()
 
@@ -91,6 +92,10 @@ def load_contents_from_local_file(file_type: str, local_file_path: str) -> Dict:
     if not os.path.isfile(local_file_path):
         fail_out(f'Failed to find file: {local_file_path}')
 
+    # Check if file is completely empty
+    if os.stat(local_file_path).st_size == 0:
+        return {}
+
     logger.debug(f"Loading specified local .{file_type} file: '{local_file_path}' ...")
     try:
         with open(local_file_path, 'r') as open_file:
@@ -99,7 +104,7 @@ def load_contents_from_local_file(file_type: str, local_file_path: str) -> Dict:
             elif file_type == 'toml':
                 file_contents = toml.load(open_file)
             elif file_type == 'json':
-                file_contents = json.load(open_file)
+                file_contents = json.loads(open_file.read())
             else:
                 logger.debug(f"Unknown file type passed: '{file_type}'")
                 raise ValueError(f"Unknown file type passed: '{file_type}'")
@@ -112,7 +117,7 @@ def load_contents_from_local_file(file_type: str, local_file_path: str) -> Dict:
 def load_contents_from_remote_file_url(file_type: str, remote_file_url: str, allow_redirects: bool = True) -> Dict:
     """Loading a remote yaml file contents over HTTP
 
-    # FIXME: Make it able to load toml, json, and yaml file types
+    ### FIXME: Make it able to load toml, json, and yaml file types
 
     Args:
         file_type (str)       : Type of file to be loaded ie. 'yaml', 'toml', 'json'
@@ -248,12 +253,12 @@ def is_list_items_in_dict(list_items: list, dict_to_check: dict) -> int:
 
 
 def iter_data_empty_item_stripper(iter_data):
-    """Removes any empty data form a nested or un-nested iter item
+    """Removes any empty data from a nested or un-nested iter item
 
     Details: https://stackoverflow.com/a/27974027/11294572
 
     Args:
-        iter_data : data in the form of iterable (ie. list, dict, set, etc)
+        iter_data : data in the from of iterable (ie. list, dict, set, etc)
 
     Returns:
         Iterable item without any blank/empty items
@@ -547,7 +552,7 @@ def item_subitem_list(item_info: Dict,
 
 def to_seconds(time_quantity: int, time_unit_text: str) -> int:
     """
-    Get the number of seconds form the time quantity and time unit type.
+    Get the number of seconds from the time quantity and time unit type.
     Examples:
         - 45 min -> 2700 seconds
         - 2 days -> 432000 seconds
@@ -653,7 +658,7 @@ def remove_special_char(text: str, special_chars: str = '@!#$%^&*<>?/\|~:') -> s
     """
     regex = re.compile('[' + special_chars + ']')
     text_new = re.sub(regex, '', text)
-    logger.debug(f'Removed special characters "{special_chars}" form string')
+    logger.debug(f'Removed special characters "{special_chars}" from string')
     return text_new
 
 
